@@ -33,7 +33,28 @@ app = typer.Typer(
 )
 console = Console()
 
-# Global options
+from .installer import cleanup_old_cache, global_cache_dir
+
+def clear_cache_command(max_age_days: Optional[int] = None):
+    """Clear the package cache."""
+    cache_dir = global_cache_dir()
+    try:
+        if max_age_days is not None:
+            console.print(f"[yellow]Cleaning cache older than {max_age_days} days...[/]")
+            cleanup_old_cache(max_age_days)
+            console.print("[green]✓ Cache cleanup completed")
+        else:
+            if cache_dir.exists():
+                import shutil
+                shutil.rmtree(cache_dir)
+                cache_dir.mkdir(parents=True)
+                console.print(f"[green]✓ Successfully cleared package cache at: {cache_dir}")
+            else:
+                console.print("[yellow]ℹ️  Package cache is already empty")
+    except Exception as e:
+        console.print(f"[red]Error clearing cache: {e}")
+        raise typer.Exit(1)
+
 @app.callback()
 def _global_options(
     logs: bool = typer.Option(False, "--logs", help="Show detailed command output (verbose)"),
@@ -48,7 +69,21 @@ def _global_options(
 # ----------------------------
 # Helpers
 # ----------------------------
-
+@app.command(name="clear-cache")
+def clear_cache_cmd(
+    max_age: Optional[int] = typer.Option(
+        None,
+        "--max-age",
+        help="Clear cache older than X days (default: clear all)"
+    )
+):
+    """Clear the package cache.
+    
+    Examples:
+        pydep clear-cache          # Clear entire cache
+        pydep clear-cache --max-age 30  # Clear cache older than 30 days
+    """
+    clear_cache_command(max_age)
 def _normalize_name(name: str) -> str:
     return name.replace("-", "_")
 
@@ -75,9 +110,9 @@ def _parse_add_args(pkgs: List[str]) -> list[tuple[str, str]]:
 
 @app.command()
 def version():
-    """Show PyDM version."""
+    """Show PyDepM version."""
     from . import __version__
-    console.print(f"PyDM {__version__}")
+    console.print(f"PyDepM {__version__}")
 
 
 @app.command()
@@ -102,25 +137,56 @@ def init(
     if type == "module" and pyproject is not None:
         console.print("[yellow]Note: --pyproject flag is ignored for module type as pyproject.toml is always generated.")
     
-    # If no name provided and it's a module, prompt for name
-    if name is None and type == "module":
+    # Always ask for project name if not provided
+    if name is None:
         name = typer.prompt("Enter project name")
+        if not name.strip():
+            console.print("[red]Project name cannot be empty!")
+            raise typer.Exit(1)
     
-    if name:
-        # Create new directory structure
+    # Ask for project type if not provided via command line
+    if type == "app":  # If using default value, ask for confirmation/choice
+        console.print("\n[bold]Project type:[/bold]")
+        console.print("1. app - Simple application with main.py")
+        console.print("2. module - Python package with CLI entry points")
+        
+        type_choice = typer.prompt(
+            "Choose project type (1 or 2)", 
+            type=str, 
+            default="1"
+        ).strip()
+        
+        if type_choice == "1":
+            type = "app"
+        elif type_choice == "2":
+            type = "module"
+        else:
+            console.print("[red]Invalid choice. Using 'app' as default.")
+            type = "app"
+    
+    console.print(f"[green]Selected project type: {type}")
+    # ← FIN DE LA PARTE NUEVA ↑
+    
+    # Ask if user wants full project structure (esta parte ya existe)
+    create_full_structure = typer.confirm(
+        "Do you want to create the full project structure?",
+        default=True,
+    )
+    
+    target = None
+    cwd = None
+    
+    if create_full_structure:
+        # Create full directory structure (existing logic)
         target = Path(os.getcwd()) / name
         if target.exists():
             console.print(f"[red]Directory already exists: {target}")
             raise typer.Exit(1)
             
-        console.print(f"[green]Creating project at {target}")
+        console.print(f"[green]Creating project structure at {target}")
         target.mkdir(parents=True, exist_ok=False)
         cwd = str(target)
         
-        # Only create README for module projects without a name (current directory init)
-        if type == "module" and not name:
-            (target / "README.md").write_text(f"# {name or 'My Project'}\n\nProject created with PyDM.\n", encoding="utf-8")
-        
         # Create type-specific structure
         if type == "module":
             pkg_name = _normalize_name(name)
@@ -147,8 +213,8 @@ if __name__ == "__main__":
 '''
             (module_dir / "main.py").write_text(main_content, encoding="utf-8")
             
-            # For module type, we don't create pyproject.toml by default anymore
-            # It will be created when running pydep convert --to toml if needed
+            # Create README for module projects
+            (target / "README.md").write_text(f"# {name}\n\nModule project created with PyDM.\n", encoding="utf-8")
             
         else:
             # app by default
@@ -163,35 +229,43 @@ if __name__ == "__main__":
     main()
 '''
             (target / "main.py").write_text(main_content.lstrip(), encoding="utf-8")
+            (target / "README.md").write_text(f"# {name}\n\nApp project created with PyDM.\n", encoding="utf-8")
     else:
-        # Initialize current directory
-        cwd = None
-        console.print("[green]Initializing project in current directory...")
+        # Minimal structure - ONLY pypackage.json in current directory
+        # NO directories, NO module folders, NO additional files
+        console.print(f"[green]Creating minimal project '{name}' in current directory...")
+        cwd = os.getcwd()
     
-    # Initialize the package
+    # Initialize the package (creates pypackage.json)
     with console.status("Configuring project..."):
-        init_pypackage(cwd=cwd, pkg_type=type, name=name, globaldeps=globaldeps, pyproject_use=pyproject)
+        # Pasar create_module_structure=False cuando no se quiere estructura completa
+        init_pypackage(
+            cwd=cwd, 
+            pkg_type=type, 
+            name=name, 
+            globaldeps=globaldeps, 
+            pyproject_use=pyproject,
+            create_module_structure=create_full_structure  # ← Nuevo parámetro
+        )
     
-    if name:
+    if create_full_structure:
         console.print(f"[green]Project created at {target}")
+        console.print("\nNext steps:")
+        console.print(f"1. cd {name} && pydep install")
+        console.print(f"2. cd {name} && pydep run dev")
     else:
-        console.print("[green]Project initialized in current directory")
-        
-    console.print("\nNext steps:")
-    console.print(f"1. {'cd ' + str(target) + ' && ' if name else ''}pydep install")
-    console.print(f"2. {'cd ' + str(target) + ' && ' if name else ''}pydep run dev")
-
+        console.print(f"[green]Minimal project '{name}' initialized in current directory")
+        console.print("[yellow]Note: Only pypackage.json was created. No additional files or folders were generated.")
+        console.print("\nNext steps:")
+        console.print("1. pydep install")
+        console.print("2. pydep run dev")
 
 @app.command()
 def install(
     editable: bool = typer.Option(False, "-e", "--editable", help="Install the current project in editable mode"),
     g: bool = typer.Option(False, "-g", "--global", help="Install into global Python site (no venv) for this command")
 ):
-    """Install the current project or its dependencies.
-    
-    Without --editable, installs dependencies from pypackage.json.
-    With --editable, installs the current project in development mode.
-    """
+    """Install the current project or its dependencies."""
     try:
         pkg = PyPackage.load()
     except FileNotFoundError as e:
@@ -205,21 +279,21 @@ def install(
     if editable:
         project_dir = pkg.path().parent
         pyproject_path = project_dir / "pyproject.toml"
+        temp_pyproject_created = False
         
-        # Generate pyproject.toml in the project root
         try:
-            # Generate the pyproject.toml
-            pkg.to_pyproject(pyproject_path)
+            # Generate pyproject.toml in the project root
+            if not pyproject_path.exists():
+                pkg.to_pyproject(pyproject_path)
+                temp_pyproject_created = True
             
             # Install in editable mode
             cmd = [sys.executable, "-m", "pip", "install", "-e", "."]
             if g:
                 cmd.insert(1, "--user")
             
-            # Debug: Show the command and working directory
             console.print(f"[yellow]Running: {' '.join(cmd)} in {project_dir}")
             
-            # Run the command
             result = subprocess.run(
                 cmd,
                 cwd=project_dir,
@@ -228,7 +302,6 @@ def install(
                 text=True
             )
             
-            # Show command output for debugging
             if result.stdout:
                 console.print(result.stdout)
             if result.stderr:
@@ -244,33 +317,59 @@ def install(
                 
         except Exception as e:
             console.print(f"[red]Error during editable install: {str(e)}")
-            import traceback
-            console.print(traceback.format_exc())
+            # Mantener pyproject.toml para depuración en caso de error
+            console.print("[yellow]pyproject.toml kept for debugging purposes")
             raise typer.Exit(1)
             
         finally:
-            # Clean up the pyproject.toml if it was created by us
-            if pyproject_path.exists() and not (project_dir / ".pydmconf" / "pyproject.toml").exists():
+            # Solo eliminar si fue creado por nosotros y la instalación fue exitosa
+            if temp_pyproject_created and pyproject_path.exists():
                 try:
-                    pyproject_path.unlink()
+                    # Verificar que no existe una versión en el directorio de configuración
+                    config_pyproject = project_dir / ".pydep" / "pyproject.toml"
+                    if not config_pyproject.exists():
+                        pyproject_path.unlink()
+                        console.print("[green]✓ Temporary pyproject.toml cleaned up")
                 except Exception as e:
                     console.print(f"[yellow]Warning: Could not remove temporary pyproject.toml: {e}")
     else:
         # Normal dependency installation
         install_all(str(pkg.path().parent), use_global=g)
+        
+        # Update versions in pypackage.json
+        modified = False
+        with console.status("[cyan]Updating package versions in pypackage.json..."):
+            # Check main dependencies
+            for name, version in pkg.dependencies.items():
+                if not version:  # If no version specified
+                    ver = get_installed_version(name)
+                    if ver:
+                        pkg.dependencies[name] = f"=={ver}"
+                        modified = True
+            
+            # Check optional dependencies
+            for group, deps in pkg.optionalDependencies.items():
+                for name, version in deps.items():
+                    if not version:  # If no version specified
+                        ver = get_installed_version(name)
+                        if ver:
+                            deps[name] = f"=={ver}"
+                            modified = True
+        
+        if modified:
+            pkg.save()
+            console.print("[green]✓ Updated package versions in pypackage.json")
+        else:
+            console.print("[green]✓ All dependencies are up to date")
 
 
 @app.command()
 def add(
-    packages: List[str] = typer.Argument(..., help="Packages to add (e.g., requests==2.32.0 or typer^0.12.3)"),
-    g: bool = typer.Option(False, "-g", "--global", help="Install package(s) globally (no venv) for this command"),
+    packages: List[str] = typer.Argument(..., help="Packages to add"),
+    g: bool = typer.Option(False, "-g", "--global", help="Install package(s) globally"),
     no_deps: bool = typer.Option(False, "--no-deps", help="Install packages without their dependencies")
 ):
-    """Add one or more dependencies to pypackage.json and install them.
-    
-    By default, all dependencies will be installed. Use --no-deps to install only
-    the specified packages without their dependencies.
-    """
+    """Add one or more dependencies to pypackage.json and install them."""
     if g:
         set_global_deps_override(True)
     try:
@@ -280,68 +379,58 @@ def add(
         raise typer.Exit(1)
 
     parsed = _parse_add_args(packages)
-    # Track packages without a specifier to pin exact version afterwards
     no_spec = {name for name, spec in parsed if not (spec or "").strip()}
+    
+    # Update pypackage.json first
     for name, spec in parsed:
         pkg.dependencies[name] = spec or ""
     pkg.save()
 
-    # Normalize requirements for pip
+    # Prepare requirements for pip
     reqs: list[str] = []
     for name, spec in parsed:
         s = spec.strip()
         if s.startswith("^"):
+            # Convert caret to pip compatible
             base = s[1:]
             parts = base.split(".")
             try:
                 major = int(parts[0])
-                upper = f"<{major+1}.0.0"
-                reqs.append(f"{name}>={base},{upper}")
-            except Exception:
+                reqs.append(f"{name}>={base},<{major+1}.0.0")
+            except (ValueError, IndexError):
                 reqs.append(f"{name}{s}")
         else:
-            # Si no se especifica versión, usamos >= para permitir actualizaciones de parche
             reqs.append(f"{name}{s}" if s else name)
 
-    # Preparar argumentos para pip
+    # Install with pip
     pip_args = ["--upgrade"]
     if no_deps:
         pip_args.append("--no-deps")
     
-    # Primero intentamos instalar sin restricciones de versión para permitir que pip resuelva los conflictos
-    with console.status("[cyan]Resolving dependencies..."):
-        if no_deps:
-            # Si --no-deps está activado, instalamos directamente las versiones especificadas
-            code = install_packages(pip_args + reqs)
-        else:
-            # Intento 1: Instalar sin restricciones de versión
-            temp_reqs = [req.split("==")[0].split("<")[0].split(">")[0].split("~")[0].split("^")[0] for req in reqs]
-            code = install_packages(pip_args + temp_reqs)
-            
-            if code != 0:
-                # Intento 2: Si falla, intentamos con las restricciones originales
-                console.print("[yellow]Warning: Could not resolve dependencies with flexible versions. Trying with exact versions...")
-                code = install_packages(pip_args + reqs)
-                if code != 0:
-                    console.print("[red]Error: Could not resolve package dependencies. Try one of these solutions:")
-                    console.print("1. Use --no-deps to install without dependencies")
-                    console.print("2. Specify version constraints manually, e.g.: pydep add 'requests>=2.25.0,<3.0.0'")
-                    raise typer.Exit(code)
+    with console.status("[cyan]Installing packages..."):
+        code = install_packages(pip_args + reqs)
+        if code != 0:
+            console.print("[red]Error: Could not install packages.")
+            console.print("Try one of these solutions:")
+            console.print("1. Use --no-deps to install without dependencies")
+            console.print("2. Check package names and versions")
+            raise typer.Exit(code)
 
-    # Pin exact versions for those without specifier
+    # Set exact versions for packages without specifier
     modified = False
-    with console.status("[cyan]Pinning exact versions..."):
-        for name in no_spec:
-            ver = get_installed_version(name)
-            if ver:
-                pkg.dependencies[name] = f"=={ver}"
-                modified = True
-    if modified:
-        pkg.save()
-        console.print("[green]Dependencies updated with exact versions in pypackage.json")
+    if not no_deps:  # Only if installing dependencies
+        with console.status("[cyan]Pinning exact versions..."):
+            for name in no_spec:
+                ver = get_installed_version(name)
+                if ver:
+                    pkg.dependencies[name] = f"=={ver}"
+                    modified = True
+        if modified:
+            pkg.save()
+            console.print("[green]Dependencies updated with exact versions in pypackage.json")
+    
     raise typer.Exit(0)
 
-
 @app.command()
 def remove(packages: List[str] = typer.Argument(..., help="Packages to remove"), g: bool = typer.Option(False, "-g", "--global", help="Remove from global site-packages for this command")):
     """Remove one or more dependencies from pypackage.json and uninstall from the environment."""
@@ -364,7 +453,10 @@ def remove(packages: List[str] = typer.Argument(..., help="Packages to remove"),
 
 
 @app.command("run")
-def run_cmd(script: str = typer.Argument(..., help="Script name defined in pypackage.json")):
+def run_cmd(
+    script: str = typer.Argument(..., help="Script name defined in pypackage.json"),
+    interactive: bool = typer.Option(True, "--interactive/--non-interactive", help="Ask before creating virtual environment")
+):
     """Run a script defined in pypackage.json (equivalent to npm run)."""
     try:
         pkg = PyPackage.load()
@@ -377,8 +469,14 @@ def run_cmd(script: str = typer.Argument(..., help="Script name defined in pypac
         console.print(f"[red]Script '{script}' not found in pypackage.json")
         raise typer.Exit(1)
 
-    # Asegura venv para comandos python si se desea
-    ensure_venv()
+    # Asegura venv para comandos python - AÑADIR interactive
+    try:
+        venv_python = ensure_venv(interactive=interactive)
+        if venv_python is None:
+            console.print("[yellow]Using system Python instead of virtual environment.")
+    except RuntimeError as e:
+        console.print(f"[red]Error: {e}")
+        raise typer.Exit(1)
 
     console.print(f"[cyan]Running: {cmd}")
     
@@ -403,7 +501,6 @@ def run_cmd(script: str = typer.Argument(..., help="Script name defined in pypac
         console.print(f"[red]Error running script: {e}")
         exit_code = 1
     
-    # Si llegamos aquí, el proceso terminó (bien o mal)
     raise typer.Exit(exit_code)
 
 @app.command()
@@ -415,15 +512,15 @@ def build():
         console.print("[red]pypackage.json not found in the current directory")
         raise typer.Exit(1)
     
-    # Ensure .pydepconf directory exists
-    config_dir = Path(".pydepconf")
+    # Ensure .pydep directory exists
+    config_dir = Path(".pydep")
     config_dir.mkdir(exist_ok=True)
     
-    # Generate pyproject.toml in .pydmconf only if needed
+    # Generate pyproject.toml in .pydep only if needed
     pyproject_path = None
     if pkg.type == "module" or (pkg.type == "app" and getattr(pkg, 'pyprojectUse', False)):
         pyproject_path = config_dir / "pyproject.toml"
-        console.print("[cyan]Generating pyproject.toml in .pydepconf directory...")
+        console.print("[cyan]Generating pyproject.toml in .pydep directory...")
         pkg.to_pyproject(pyproject_path)
     
     # Handle module type with build
@@ -593,15 +690,169 @@ def build():
 
 @app.command()
 def convert(
-    to: str = typer.Option("toml", "--to", help="Conversion type: toml or lock"),
+    to: str = typer.Option(None, "--to", help="Conversion type: toml or lock"),
+    from_format: Optional[str] = typer.Option(
+        None, 
+        "--from", 
+        help="Source format to convert from (toml)"
+    ),
     hashes: bool = typer.Option(False, "--hashes/--no-hashes", help="Include sha256 hashes in the lockfile (disabled by default for speed)"),
     outdir: Optional[Path] = typer.Option(None, "--outdir", "-o", help="Output directory for the generated file (default: current directory for lock, .pydepconf for toml)"),
 ):
-    """Convert pypackage.json to other formats.
+    """Convert between different package configuration formats.
     
-    By default, pyproject.toml is generated in the .pydmconf directory,
-    while pypackage-lock.json is generated in the current directory.
+    By default, converts pypackage.json to pyproject.toml in the current directory.
+    Use --from toml to convert from pyproject.toml to pypackage.json.
     """
+    # Validate formats
+    if from_format and from_format not in ["toml"]:
+        console.print("[red]Error: Only 'toml' is supported as source format[/]")
+        raise typer.Exit(1)
+
+    if to and to not in ["toml", "lock"]:
+        console.print("[red]Error: Only 'toml' or 'lock' are supported as target formats[/]")
+        raise typer.Exit(1)
+
+    if from_format == "toml":
+        if to == "lock":
+            console.print("[red]Error: Cannot convert directly from toml to lock. Please convert to pypackage.json first.[/]")
+            raise typer.Exit(1)
+        convert_from_toml(outdir)
+    elif to:
+        convert_to_format(to, hashes, outdir)
+    else:
+        # Default behavior if no --to or --from is specified
+        convert_to_format("toml", hashes, outdir)
+
+def convert_from_toml(outdir: Optional[Path] = None):
+    """Convert from pyproject.toml to pypackage.json."""
+    import toml
+    from datetime import datetime
+    import re
+    
+    console.print("[cyan]Converting from pyproject.toml to pypackage.json...[/]")
+    
+    # Check if pyproject.toml exists
+    toml_path = Path("pyproject.toml")
+    if not toml_path.exists():
+        console.print("[red]Error: pyproject.toml not found in current directory[/]")
+        raise typer.Exit(1)
+    
+    # Load the TOML content
+    try:
+        with open(toml_path, "r", encoding="utf-8") as f:
+            toml_content = toml.load(f)
+    except Exception as e:
+        console.print(f"[red]Error reading pyproject.toml: {e}[/]")
+        raise typer.Exit(1)
+    
+    # Create basic pypackage structure
+    project = toml_content.get("project", {})
+    pkg = {
+        "type": "module",  # Default to module type when converting from pyproject.toml
+        "name": project.get("name", "my-module"),
+        "version": project.get("version", "0.1.0"),
+        "description": project.get("description", ""),
+        "authors": project.get("authors", [{"name": "PyDepM User"}]),
+        "license": project.get("license", "MIT"),
+        "dependencies": {},
+        "optionalDependencies": {},
+        "cli": project.get("scripts", {}),
+        "pyproject": {
+            "_raw": toml.dumps(toml_content)  # Store original TOML content
+        }
+    }
+    
+    def parse_dependency(dep):
+        """Parse a dependency string into name and version specifier.
+        
+        Handles various formats:
+        - "package" -> ("package", "")
+        - "package>=1.0.0" -> ("package", ">=1.0.0")
+        - "package[extra]>=1.0.0" -> ("package[extra]", ">=1.0.0")
+        - "git+https://..." -> ("git+https://...", "")
+        """
+        # Handle git+ URLs and other direct references
+        if any(dep.startswith(prefix) for prefix in ["git+", "hg+", "svn+", "bzr+"]):
+            return dep, ""
+            
+        # Handle package with extras: package[extra1,extra2]>=1.0.0
+        if "[" in dep and "]" in dep and dep.index("[") < dep.index("]"):
+            # Find the end of the extras section
+            end_extras = dep.index("]") + 1
+            name_part = dep[:end_extras]
+            version_part = dep[end_extras:].strip()
+            
+            # If there's a version part, parse it
+            if version_part and version_part[0] in "=<>~!^":
+                version = version_part
+            else:
+                version = ""
+            
+            return name_part, version
+        
+        # Handle standard version specifiers
+        for op in [">=", "==", ">", "<=", "<", "~=", "!=", "^", "~"]:
+            if dep.startswith(op):
+                continue  # Skip if the dependency itself starts with an operator
+                
+            # Use regex to match the operator followed by a version number
+            # This handles cases like "package>=1.0.0,<2.0.0"
+            match = re.match(fr'^(.+?)({re.escape(op)}[^,;\s]+)(.*)$', dep)
+            if match:
+                name = match.group(1).strip()
+                version = match.group(2).strip()
+                rest = match.group(3).strip()
+                
+                # Handle multiple version specifiers
+                if rest and rest[0] == ",":
+                    version += rest
+                
+                return name, version
+        
+        # If no version specifier found, return the whole string as name
+        return dep.strip(), ""
+    
+    # Convert main dependencies
+    for dep in project.get("dependencies", []):
+        name, version = parse_dependency(dep)
+        if name:  # Only add if we have a valid name
+            pkg["dependencies"][name] = version if version else "*"
+    
+    # Convert optional dependencies
+    for group, deps in project.get("optional-dependencies", {}).items():
+        pkg["optionalDependencies"][group] = {}
+        for dep in deps:
+            name, version = parse_dependency(dep)
+            if name:  # Only add if we have a valid name
+                pkg["optionalDependencies"][group][name] = version if version else "*"
+    
+    # Process entry points (console_scripts)
+    if "project" in toml_content and "entry-points" in toml_content["project"]:
+        entry_points = toml_content["project"]["entry-points"]
+        if "console_scripts" in entry_points:
+            for name, path in entry_points["console_scripts"].items():
+                pkg["cli"][name] = path
+    
+    # Create .old directory if it doesn't exist
+    old_dir = Path(".old")
+    old_dir.mkdir(exist_ok=True)
+    
+    # Move pyproject.toml to .old directory with timestamp
+    timestamp = datetime.now().strftime("%Y%m%d_%H%M%S")
+    backup_path = old_dir / f"pyproject.toml.{timestamp}"
+    toml_path.rename(backup_path)
+    console.print(f"[yellow]Moved original pyproject.toml to {backup_path}[/]")
+    
+    # Write the new pypackage.json
+    output_file = Path("pypackage.json")
+    with open(output_file, "w", encoding="utf-8") as f:
+        json.dump(pkg, f, indent=2, ensure_ascii=False)
+    
+    console.print(f"[green]Successfully created {output_file.absolute()}[/]")
+
+def convert_to_format(to: str, hashes: bool, outdir: Optional[Path] = None):
+    """Convert pypackage.json to the specified format."""
     try:
         pkg = PyPackage.load()
     except FileNotFoundError:
@@ -620,7 +871,7 @@ def convert(
         console.print(f"[green]Lockfile generated at: {output_file.absolute()}")
         return
     
-    # For TOML, use the specified output directory or .pydepconf
+    # For TOML, use the specified output directory or current directory
     if to == "toml":
         if outdir is None:
             # Default to current directory for backward compatibility
@@ -645,10 +896,18 @@ def convert(
 @app.command()
 def audit(
     json_output: bool = typer.Option(False, "--json", help="Show raw JSON output from pip-audit"),
-    extended: bool = typer.Option(False, "--extended", help="Also show packages with no known vulnerabilities")
+    extended: bool = typer.Option(False, "--extended", help="Also show packages with no known vulnerabilities"),
+    interactive: bool = typer.Option(True, "--interactive/--non-interactive", help="Ask before creating virtual environment")
 ):
     """Audit dependencies using pip-audit and show a concise summary (no --logs required)."""
-    ensure_venv()
+    try:
+        venv_python = ensure_venv(interactive=interactive)
+        if venv_python is None:
+            console.print("[yellow]Using system Python for audit (no virtual environment).")
+    except RuntimeError as e:
+        console.print(f"[red]Error: {e}")
+        raise typer.Exit(1)
+    
     ensure_tool("pip-audit")
 
     if json_output:
