@@ -66,7 +66,7 @@ class BaseModel:
         return json.dumps(self.dict(), **kwargs)
 
 console = Console()
-CONFIG_DIR = ".pydmconf"
+CONFIG_DIR = ".pydep"
 
 def get_config_dir(create: bool = True) -> Path:
     """Get the path to the config directory, optionally creating it if it doesn't exist.
@@ -165,8 +165,12 @@ class PyPackage(BaseModel):
     def load(cls, cwd: Optional[str] = None) -> "PyPackage":
         path = cls.path(cwd)
         if not path.exists():
-            raise FileNotFoundError("pypackage.json not found. Run 'pydm init' or 'pydm new'.")
-        data = json.loads(path.read_text(encoding="utf-8"))
+            raise FileNotFoundError("pypackage.json not found. Run 'pydm init'.")
+        
+        # Usar validación segura
+        from .validation import safe_load_pypackage
+        data = safe_load_pypackage(path)
+        
         return cls(**data)
 
     def save(self, cwd: Optional[str] = None) -> None:
@@ -236,21 +240,14 @@ class PyPackage(BaseModel):
                     current[parts[-1]] = value
             
             # Deep merge structured content
-            def deep_merge(dest, source):
-                for key, value in source.items():
-                    if key in dest and isinstance(dest[key], dict) and isinstance(value, dict):
-                        deep_merge(dest[key], value)
-                    else:
-                        dest[key] = value
-            
-            deep_merge(pyproject, structured_content)
+            self.deep_merge(pyproject, structured_content)
             
             # Handle raw content if provided
             if "_raw" in self.pyproject and isinstance(self.pyproject["_raw"], str):
                 try:
                     import toml
                     raw_content = toml.loads(self.pyproject["_raw"])
-                    deep_merge(pyproject, raw_content)
+                    self.deep_merge(pyproject, raw_content)
                 except Exception as e:
                     console.print(f"[yellow]Warning: Could not parse _raw pyproject content: {e}")
         
@@ -289,6 +286,15 @@ class PyPackage(BaseModel):
         
         return pyproject
 
+    @staticmethod
+    def deep_merge(dest, source):
+        """Deep merge two dictionaries."""
+        for key, value in source.items():
+            if key in dest and isinstance(dest[key], dict) and isinstance(value, dict):
+                PyPackage.deep_merge(dest[key], value)
+            else:
+                dest[key] = value
+
     def to_pyproject(self, path: Optional[Union[str, Path]] = None, *, skip_validation: bool = False) -> Path:
         """Generate a pyproject.toml file from this package.
         
@@ -300,20 +306,26 @@ class PyPackage(BaseModel):
             Path to the generated pyproject.toml file
         """
         if path is None:
-            path = self.path().parent / ".pydmconf" / "pyproject.toml"
+            path = self.path().parent / ".pydepconf" / "pyproject.toml"
         else:
             path = Path(path)
             
         path.parent.mkdir(parents=True, exist_ok=True)
         
-        # If there's custom raw content, write it directly
+        # Always generate the base pyproject content
+        pyproject_content = self.get_pyproject_content()
+        
+        # If there's custom raw content, merge it with the generated content
         if hasattr(self, 'pyproject') and isinstance(self.pyproject, dict) and "_raw" in self.pyproject:
             try:
+                import toml
                 if isinstance(self.pyproject["_raw"], str):
-                    path.write_text(self.pyproject["_raw"], encoding='utf-8')
-                    return path
+                    # Parse the raw content
+                    raw_content = toml.loads(self.pyproject["_raw"])
+                    # Merge with generated content (raw content takes precedence)
+                    self.deep_merge(pyproject_content, raw_content)
             except Exception as e:
-                console.print(f"[yellow]Warning: Could not write raw pyproject content: {e}")
+                console.print(f"[yellow]Warning: Could not parse _raw pyproject content: {e}")
                 console.print("[yellow]Falling back to generated content...")
         
         # Generate and write the pyproject content
@@ -340,7 +352,7 @@ class PyPackage(BaseModel):
             raise
 
 
-def init_pypackage(cwd: Optional[str] = None, pkg_type: str = "app", name: Optional[str] = None, globaldeps: bool = False, pyproject_use: Optional[bool] = None) -> PyPackage:
+def init_pypackage(cwd: Optional[str] = None, pkg_type: str = "app", name: Optional[str] = None, globaldeps: bool = False, pyproject_use: Optional[bool] = None, create_module_structure: bool = True) -> PyPackage:
     path = PyPackage.path(cwd)
     if path.exists():
         console.print("[yellow]pypackage.json already exists. Skipping creation.")
@@ -368,7 +380,7 @@ def init_pypackage(cwd: Optional[str] = None, pkg_type: str = "app", name: Optio
         data.update({
             "description": "This is a simple module autogenerated with PyDM.",
             "scripts": {
-                "start": f"python -m {module_name}"
+                "dev": f"python {module_name}/main.py"
             },
             "cli": {
                 module_name: {
@@ -410,13 +422,6 @@ def init_pypackage(cwd: Optional[str] = None, pkg_type: str = "app", name: Optio
                 "build-system": {
                     "requires": ["setuptools>=42", "wheel"],
                     "build-backend": "setuptools.build_meta"
-                },
-                "project": {
-                    "entry-points": {
-                        "console_scripts": [
-                            f"{module_name} = {module_name}.main:main"
-                        ]
-                    }
                 }
             }
     
@@ -425,8 +430,9 @@ def init_pypackage(cwd: Optional[str] = None, pkg_type: str = "app", name: Optio
     
     pkg = PyPackage(**data)
     pkg.save(cwd)
-        # Create default module structure for module type
-    if pkg_type == "module":
+    
+    # SOLO crear estructura del módulo si create_module_structure es True
+    if pkg_type == "module" and create_module_structure:
         module_dir = Path(cwd or ".") / module_name
         module_dir.mkdir(exist_ok=True)
         
@@ -452,4 +458,4 @@ if __name__ == "__main__":
         console.print(f"[green]Created module structure in {module_dir}")
     
     console.print(f"[green]Created {path}")
-    return pkg
+    return pkg
\ No newline at end of file
