@@ -89,22 +89,69 @@ def _confirm_yn(prompt: str, default: bool = True) -> bool:
         console.print("[yellow]Please enter 'y' or 'n'[/]")
 
 
-def ensure_venv(cwd: Optional[str] = None, python: Optional[str] = None) -> Path:
+def ensure_venv(cwd: Optional[str] = None, python: Optional[str] = None, interactive: bool = False) -> Optional[Path]:
+    """Ensure virtual environment exists. Returns path to venv Python or None if user declines."""
     # If project is configured to use global dependencies, return system python
     if _use_global_deps(cwd):
         return Path(sys.executable)
         
     vdir = venv_dir(cwd)
     if not vdir.exists():
-        console.print(f"[yellow]No virtual environment found at {vdir}[/]")
-        if not _confirm_yn("Do you want to create a virtual environment? [Y/n] ", default=True):
-            raise RuntimeError("Operation cancelled: Virtual environment is required")
+        if not interactive:
+            console.print(f"[cyan]Creating virtual environment at {vdir}...")
+            # For Python 3.11+, we don't need --with-pip as pip is included by default
+            cmd = [python or sys.executable, "-m", "venv", str(vdir)]
+            code = run(cmd)
+            if code != 0:
+                raise RuntimeError("Failed to create virtual environment")
             
-        console.print(f"[cyan]Creating virtual environment at {vdir}...")
-        cmd = [python or sys.executable, "-m", "venv", str(vdir)]
-        code = run(cmd)
-        if code != 0:
-            raise RuntimeError("Failed to create virtual environment")
+            # Ensure pip is properly installed and up-to-date
+            python_exe = venv_python(cwd)
+            ensure_pip_cmd = [str(python_exe), "-m", "ensurepip", "--upgrade"]
+            pip_cmd = [str(python_exe), "-m", "pip", "install", "--upgrade", "pip"]
+            
+            # First ensure pip is installed
+            ensure_code = run(ensure_pip_cmd, cwd=cwd)
+            if ensure_code != 0:
+                console.print("[yellow]Warning: Failed to ensure pip is installed in the virtual environment")
+                return python_exe
+                
+            # Then upgrade pip
+            pip_code = run(pip_cmd, cwd=cwd)
+            if pip_code != 0:
+                console.print("[yellow]Warning: Failed to upgrade pip in the virtual environment")
+                
+            return python_exe
+        else:
+            # Preguntar al usuario si quiere crear el venv
+            if not _confirm_yn(f"[yellow]No virtual environment found at {vdir}. Do you want to create one?", default=True):
+                console.print("[yellow]Using system Python (no virtual environment).")
+                return None
+                
+            console.print(f"[cyan]Creating virtual environment at {vdir}...")
+            cmd = [python or sys.executable, "-m", "venv", str(vdir)]
+            code = run(cmd)
+            if code != 0:
+                raise RuntimeError("Failed to create virtual environment")
+            
+            # Ensure pip is properly installed and up-to-date for interactive mode too
+            python_exe = venv_python(cwd)
+            ensure_pip_cmd = [str(python_exe), "-m", "ensurepip", "--upgrade"]
+            pip_cmd = [str(python_exe), "-m", "pip", "install", "--upgrade", "pip"]
+            
+            # First ensure pip is installed
+            ensure_code = run(ensure_pip_cmd, cwd=cwd)
+            if ensure_code != 0:
+                console.print("[yellow]Warning: Failed to ensure pip is installed in the virtual environment")
+                return python_exe
+                
+            # Then upgrade pip
+            pip_code = run(pip_cmd, cwd=cwd)
+            if pip_code != 0:
+                console.print("[yellow]Warning: Failed to upgrade pip in the virtual environment")
+                
+            return python_exe
+    
     return venv_python(cwd)
 
 
@@ -126,18 +173,45 @@ def get_installed_version(package: str, cwd: Optional[str] = None) -> Optional[s
 
 
 def global_cache_dir() -> Path:
-    """Return path to the global cache directory used by PyDM."""
+    """Return path to the global cache directory used by PyDep."""
     home = Path.home()
-    base = home / ".pydm" / "cache"
+    base = home / ".pydep" / "cache"
     base.mkdir(parents=True, exist_ok=True)
     return base
 
 
-def pip_download(packages: Iterable[str], dest: Path, cwd: Optional[str] = None) -> int:
-    """Download distributions for given package requirements into dest (no deps).
+import time
+import shutil
 
-    Note: 'packages' must be requirement specifiers only (no pip options).
-    """
+def cleanup_old_cache(max_age_days: int = 30):
+    """Eliminar paquetes del caché más antiguos que max_age_days"""
+    cache_dir = global_cache_dir()
+    if not cache_dir.exists():
+        return
+    
+    current_time = time.time()
+    removed_count = 0
+    
+    for item in cache_dir.iterdir():
+        if item.is_file():
+            # Calcular antigüedad del archivo
+            file_age = current_time - item.stat().st_mtime
+            if file_age > (max_age_days * 24 * 60 * 60):  # Convertir días a segundos
+                try:
+                    item.unlink()
+                    removed_count += 1
+                except Exception as e:
+                    console.print(f"[yellow]Warning: Could not remove {item}: {e}")
+    
+    if removed_count > 0:
+        console.print(f"[green]Cleaned up {removed_count} old package(s) from cache")
+
+# Modificar pip_download para incluir limpieza
+def pip_download(packages: Iterable[str], dest: Path, cwd: Optional[str] = None) -> int:
+    """Download distributions for given package requirements into dest (no deps)."""
+    # Limpiar caché antiguo antes de descargar
+    cleanup_old_cache()
+    
     py = ensure_venv(cwd)
     args = [str(py), "-m", "pip", "download", "--no-deps", "-d", str(dest), *list(packages)]
     return run(args, cwd=cwd)
@@ -429,30 +503,64 @@ def install_all(cwd: Optional[str] = None, use_global: bool = False) -> int:
         except Exception as e:
             console.print(f"[yellow]Invalid lockfile. Ignoring and resolving from pypackage.json. Error: {e}")
 
-    reqs = [f"{name}{spec}" if any(c in spec for c in "><=~^*") else f"{name}=={spec}" for name, spec in pkg.dependencies.items()]
-    # Interpret ^x.y.z como >=x.y.z,<x+1.0.0 de forma simple
-    norm_reqs: list[str] = []
-    for name, spec in pkg.dependencies.items():
-        s = spec.strip()
-        if s.startswith("^"):
+    # Instalar dependencias principales
+    norm_reqs = _normalize_requirements(pkg.dependencies)
+    if norm_reqs:
+        console.print("[cyan]Installing main dependencies...")
+        code = install_packages(norm_reqs, cwd=cwd)
+        if code != 0:
+            return code
+        console.print("[green]✓ Main dependencies installed")
+    else:
+        console.print("[yellow]No main dependencies to install.")
+        ensure_venv(cwd)
+    
+    # Manejar dependencias opcionales
+    if hasattr(pkg, 'optionalDependencies') and pkg.optionalDependencies:
+        console.print("\n[bold]Optional dependency groups found:[/]")
+        for group, deps in pkg.optionalDependencies.items():
+            if not deps:
+                continue
+                
+            if _confirm_yn(f"Install optional '{group}' dependencies? ({len(deps)} packages)", default=False):
+                group_reqs = _normalize_requirements(deps)
+                if group_reqs:
+                    console.print(f"[cyan]Installing {group} dependencies...")
+                    code = install_packages(group_reqs, cwd=cwd)
+                    if code == 0:
+                        console.print(f"[green]✓ {group} dependencies installed")
+                    else:
+                        console.print(f"[yellow]! Some {group} dependencies failed to install")
+    
+    return 0
+
+def _normalize_requirements(deps: dict) -> list[str]:
+    """Normalize requirements from a dict of {name: spec} to a list of pip-compatible requirements."""
+    norm_reqs = []
+    for name, spec in deps.items():
+        if not spec:
+            continue
+            
+        s = str(spec).strip()
+        if s.startswith("^") and "." in s:
+            # Manejar ^x.y.z como >=x.y.z,<x+1.0.0
             base = s[1:]
             parts = base.split(".")
             try:
                 major = int(parts[0])
                 upper = f"<{major+1}.0.0"
                 norm_reqs.append(f"{name}>={base},{upper}")
-            except Exception:
-                norm_reqs.append(f"{name}{s}")
-        else:
+                continue
+            except (ValueError, IndexError):
+                pass
+        
+        # Para cualquier otro caso, incluyendo versiones exactas o rangos complejos
+        if any(c in s for c in "=<>~!"):
             norm_reqs.append(f"{name}{s}")
-    if not norm_reqs:
-        console.print("[yellow]No dependencies to install.")
-        ensure_venv(cwd)
-        return 0
-    code = install_packages(norm_reqs, cwd=cwd)
-    if code == 0:
-        console.print("[green]Dependencies installed.")
-    return code
+        else:
+            norm_reqs.append(f"{name}=={s}")
+    
+    return norm_reqs
 
 
 def ensure_tool(package: str, cwd: Optional[str] = None) -> int:
